@@ -1,5 +1,5 @@
 """
-Based loosely on Jacob Kaplan-Moss' old Jellyroll application, probably by way of Jeff Croft. 
+Based loosely on Jacob Kaplan-Moss' old Jellyroll application, probably by way of Jeff Croft.
 The origins are hazy at this point.
 
 """
@@ -49,7 +49,12 @@ class ActionsForPeriod(ActionList):
 
         if self.day: # Get actions for a particular day
             qs = qs.filter(timestamp__year=self.year, timestamp__month=self.month, timestamp__day=self.day)
-            self.previous = datetime.date(self.year, self.month, self.day) - datetime.timedelta(days=1)
+            current_day = datetime.date(self.year, self.month, self.day)
+            self.previous = current_day - datetime.timedelta(days=1)
+            if current_day == datetime.date.today():
+                self.next = None
+            else:
+                self.next = current_day + datetime.timedelta(days=1)
         else:
             # Get actions for a particular month
             start_date = datetime.date(self.year, self.month, 1)
@@ -60,7 +65,8 @@ class ActionsForPeriod(ActionList):
 
     def get_context_data(self, **kwargs):
         context = super(ActionsForPeriod, self).get_context_data(**kwargs)
-        context['previous'] = self.previous
+        context['previous_day'] = self.previous
+        context['next_day'] = self.next
 
         # the QS is used for pagination, so let's reorganize and group them here
         context['actions'] = group_activities(self.get_queryset())
